<?php

namespace Drupal\info_messages;

use Drupal\Component\Render\MarkupInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\PageCache\ResponsePolicy\KillSwitch;
use Drupal\Core\Render\Markup;
use Symfony\Component\HttpFoundation\Session\Flash\FlashBagInterface;

class InfoMessenger implements InfoMessengerInterface {

  /**
   * The inner service(Messenger service).
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $innerService;

  /**
   * Messenger constructor.
   *
   * @param \Drupal\Core\Messenger\MessengerInterface $inner_service
   *   The messenger service.
   */
  public function __construct(MessengerInterface $inner_service) {
    $this->innerService = $inner_service;
  }

  /**
   * {@inheritdoc}
   */
  public function addInfo($message, $repeat = FALSE) {
    return $this->innerService->addMessage($message, static::TYPE_INFO, $repeat);
  }

  /**
   * {@inheritdoc}
   */
  public function addError($message, $repeat = FALSE) {
    return $this->innerService->addMessage($message, static::TYPE_ERROR, $repeat);
  }

  /**
   * {@inheritdoc}
   */
  public function addMessage($message, $type = self::TYPE_STATUS, $repeat = FALSE) {
    $this->innerService->addMessage($message, $type, $repeat);

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function addStatus($message, $repeat = FALSE) {
    return $this->innerService->addMessage($message, static::TYPE_STATUS, $repeat);
  }

  /**
   * {@inheritdoc}
   */
  public function addWarning($message, $repeat = FALSE) {
    return $this->innerService->addMessage($message, static::TYPE_WARNING, $repeat);
  }

  /**
   * {@inheritdoc}
   */
  public function all() {
    return $this->innerService->all();
  }

  /**
   * {@inheritdoc}
   */
  public function deleteAll() {
    return $this->innerService->deleteAll();
  }

  /**
   * {@inheritdoc}
   */
  public function deleteByType($type) {
    // Flash bag gets and clears flash messages from the stack.
    return $this->innerService->deleteByType($type);
  }

  /**
   * {@inheritdoc}
   */
  public function messagesByType($type) {
    return $this->innerService->messagesByType($type);
  }

}